<?php
/**
 * Configuration globale de l'application
 * Ce fichier contient toutes les constantes et paramètres de configuration
 */

// Configuration de base
define('APP_NAME', 'Blog Template');
define('APP_VERSION', '1.0.0');
define('APP_URL', 'http://localhost/blog');

// Configuration de sécurité
ini_set('session.cookie_httponly', 1);
ini_set('session.use_only_cookies', 1);
ini_set('session.cookie_secure', 1);
ini_set('session.cookie_samesite', 'Strict');

// Configuration des erreurs
error_reporting(E_ALL);
ini_set('display_errors', 0);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/logs/error.log');

// Dossiers de l'application
define('POSTS_DIR', __DIR__ . '/posts');
define('CACHE_DIR', __DIR__ . '/cache');
define('UPLOADS_DIR', __DIR__ . '/uploads');

// Création des dossiers nécessaires
$directories = [POSTS_DIR, CACHE_DIR, UPLOADS_DIR, __DIR__ . '/logs'];
foreach ($directories as $dir) {
    if (!file_exists($dir)) {
        mkdir($dir, 0755, true);
    }
}

// Configuration du fuseau horaire
date_default_timezone_set('Europe/Paris');

// Configuration de sécurité
header('X-Frame-Options: DENY');
header('X-XSS-Protection: 1; mode=block');
header('X-Content-Type-Options: nosniff');
header('Referrer-Policy: strict-origin-when-cross-origin');
header("Content-Security-Policy: default-src 'self'; script-src 'self' 'unsafe-inline'; style-src 'self' 'unsafe-inline';");

/**
 * Fonction de nettoyage des entrées utilisateur
 * @param string $data Données à nettoyer
 * @return string Données nettoyées
 */
function clean_input($data) {
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data, ENT_QUOTES, 'UTF-8');
    return $data;
}
